from django.shortcuts import render, redirect
from django.http import JsonResponse
from django.conf import settings
import time
import os
import rust_crud_api # Custom Rust Pyo3 Library 🦀

db_url = settings.DATABASE_URL

def login_view(request):
    """
    Handles user login by verifying credentials using the Rust extension.
    If valid, stores user details in the session and redirects to the account page.
    """
    db_url = settings.DATABASE_URL
    context = {}
    
    if request.method == 'POST':
        email = request.POST.get('email', '').strip()
        password = request.POST.get('password', '').strip()
        
        if not email or not password:
            context['error'] = "Email and password are required."
            return render(request, 'myapp/login.html', context)
        
        try:
            # Verify the user's credentials using the Rust extension.
            is_valid = rust_crud_api.verify_user(db_url, email, password)
            if not is_valid:
                context['error'] = "Invalid email or password."
                return render(request, 'myapp/login.html', context)
            
            # Retrieve the user record to store additional info in session.
            # (For simplicity, we retrieve all users and select the matching one.)
            users = rust_crud_api.get_all_users(db_url)
            user = next((u for u in users if u.email.lower() == email.lower()), None)
            if not user:
                context['error'] = "User not found."
                return render(request, 'myapp/login.html', context)
            
            # Store user information in the session.
            request.session['user_id'] = user.id
            request.session['user_name'] = user.name
            request.session['user_email'] = user.email
            
            return redirect('feed')
        except Exception as e:
            context['error'] = f"An error occurred: {str(e)}"
            return render(request, 'myapp/login.html', context)
    
    return render(request, 'myapp/login.html', context)

def logout_view(request):
    # Clear all session data to log out the user.
    request.session.flush()
    # Optionally, render a confirmation page or redirect to login.
    return render(request, 'myapp/logout.html')